Crate polyhook_core

Crate polyhook_core 

Re-exports

pub use types::*;

Modules

detect
events
parse
response
tools
types
wasm

Functions

read
read_from
Read a HookEvent from an arbitrary reader.
respond
respond_to
Write a HookResponse to an arbitrary writer in the format expected by the agent that was detected during the most recent read_from call.