respond_to

Function respond_to 

pub fn respond_to(
    w: &mut impl Write,
    response: &HookResponse,
) -> Result<(), String>
Write a HookResponse to an arbitrary writer in the format expected by the agent that was detected during the most recent read_from call.