Module wasm

Module wasm 

Functions

alloc⚠
Allocate len bytes and return a raw pointer.
dealloc⚠
Free memory previously allocated by alloc or returned by parse/serialize.
parse⚠
Parse raw JSON bytes into a normalised HookEvent and return it as length-prefixed JSON.
serialize⚠
Deserialise a HookResponse JSON and re-serialise it in the format expected by the caller detected during the most recent parse call.