Re-exports
pub use types::*;
Modules
Functions
- read
- read_
from - Read a
HookEventfrom an arbitrary reader. - respond
- respond_
to - Write a
HookResponseto an arbitrary writer in the format expected by the agent that was detected during the most recentread_fromcall.