pub fn normalize_event(vendor: &str, caller: &CallerKind) -> StringExpand description
Normalize a vendor-specific event name to the canonical polyhook event name.
If no mapping exists the original name is returned unchanged.
pub fn normalize_event(vendor: &str, caller: &CallerKind) -> StringNormalize a vendor-specific event name to the canonical polyhook event name.
If no mapping exists the original name is returned unchanged.