dealloc

Function dealloc 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn dealloc(ptr: *mut u8, len: usize)
Free memory previously allocated by alloc or returned by parse/serialize.

Safety

ptr must have been returned by alloc, parse, or serialize, and len must be the exact byte count that was originally allocated. Must not be called more than once for the same pointer.